@@ -78,15 +78,18 @@ defaults = dict(
   BIND_PATTERNS=['#'],
   GRAPHITE_URL='http://127.0.0.1:80',
   ENABLE_TAGS=True,
+  SKIP_TAGS_FOR_NONTAGGED=True,
   TAG_UPDATE_INTERVAL=100,
   TAG_BATCH_SIZE=100,
   TAG_QUEUE_SIZE=10000,
   TAG_HASH_FILENAMES=True,
+  TAG_RELAY_NORMALIZED=False,
   ENABLE_MANHOLE=False,
   MANHOLE_INTERFACE='127.0.0.1',
   MANHOLE_PORT=7222,
   MANHOLE_USER="",
   MANHOLE_PUBLIC_KEY="",
+  MANHOLE_HOST_KEY_DIR="",
   RELAY_METHOD='rules',
   DYNAMIC_ROUTER=False,
   DYNAMIC_ROUTER_MAX_RETRIES=5,
@@ -113,6 +116,7 @@ defaults = dict(
   TCP_KEEPINTVL=30,
   TCP_KEEPCNT=2,
   USE_RATIO_RESET=False,
+  LOG_LISTENER_CONN_LOST=False,
   LOG_LISTENER_CONN_SUCCESS=True,
   LOG_AGGREGATOR_MISSES=True,
   AGGREGATION_RULES='aggregation-rules.conf',
@@ -123,6 +127,7 @@ defaults = dict(
   CACHE_METRIC_NAMES_MAX=0,
   CACHE_METRIC_NAMES_TTL=0,
   RAVEN_DSN=None,
+  PICKLE_RECEIVER_MAX_LENGTH=2**20,
 )
 
 
@@ -350,6 +355,12 @@ class CarbonCacheOptions(usage.Options):
                 pf.close()
             except ValueError:
                 print("Failed to parse pid from pidfile %s" % pidfile)
+                pf.close()
+                try:
+                    print("removing corrupted pidfile %s" % pidfile)
+                    os.unlink(pidfile)
+                except IOError:
+                    print("Could not remove pidfile %s" % pidfile)
                 raise SystemExit(1)
             except IOError:
                 print("Could not read pidfile %s" % pidfile)
@@ -375,6 +386,12 @@ class CarbonCacheOptions(usage.Options):
                 pf.close()
             except ValueError:
                 print("Failed to parse pid from pidfile %s" % pidfile)
+                pf.close()
+                try:
+                    print("removing corrupted pidfile %s" % pidfile)
+                    os.unlink(pidfile)
+                except IOError:
+                    print("Could not remove pidfile %s" % pidfile)
                 raise SystemExit(1)
             except IOError:
                 print("Failed to read pid from %s" % pidfile)
@@ -396,6 +413,12 @@ class CarbonCacheOptions(usage.Options):
                     pf.close()
                 except ValueError:
                     print("Failed to parse pid from pidfile %s" % pidfile)
+                    pf.close()
+                    try:
+                        print("removing corrupted pidfile %s" % pidfile)
+                        os.unlink(pidfile)
+                    except IOError:
+                        print("Could not remove pidfile %s" % pidfile)
                     raise SystemExit(1)
                 except IOError:
                     print("Could not read pidfile %s" % pidfile)
@@ -584,7 +607,7 @@ def read_config(program, options, **kwargs):
         raise CarbonConfigException("Either ROOT_DIR or GRAPHITE_ROOT "
                                     "needs to be provided.")
 
-    # Default config directory to root-relative, unless overriden by the
+    # Default config directory to root-relative, unless overridden by the
     # 'GRAPHITE_CONF_DIR' environment variable.
     settings.setdefault("CONF_DIR",
                         os.environ.get("GRAPHITE_CONF_DIR",
@@ -596,7 +619,7 @@ def read_config(program, options, **kwargs):
         # file.
         settings["CONF_DIR"] = dirname(normpath(options["config"]))
 
-    # Storage directory can be overriden by the 'GRAPHITE_STORAGE_DIR'
+    # Storage directory can be overridden by the 'GRAPHITE_STORAGE_DIR'
     # environment variable. It defaults to a path relative to GRAPHITE_ROOT
     # for backwards compatibility though.
     settings.setdefault("STORAGE_DIR",
